nrf-pac

Crates

git

Versions

nrf9120

Flavors

Devid

Struct Devid 

#[repr(transparent)]
pub struct Devid(pub u32);
Device Configuration Register

Tuple Fields

0: u32

Implementations

Source

impl Devid

pub const fn extmuxnum(&self) -> u8

When non-zero this value indicates the type/number of ATB multiplexing present on the input to the ATB.

pub const fn set_extmuxnum(&mut self, val: u8)

When non-zero this value indicates the type/number of ATB multiplexing present on the input to the ATB.

pub const fn ramclk(&self) -> bool

This bit returns 0 on reads indicating that the ETB RAM operates synchronously to atclk.

pub const fn set_ramclk(&mut self, val: bool)

This bit returns 0 on reads indicating that the ETB RAM operates synchronously to atclk.