#[repr(transparent)]pub struct Ffsr(pub u32);Expand description
ETB Formatter and Flush Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Ffsr
impl Ffsr
Sourcepub const fn flinprog(&self) -> bool
pub const fn flinprog(&self) -> bool
Flush In Progress. This is an indication of the current state of afvalids.
Sourcepub const fn set_flinprog(&mut self, val: bool)
pub const fn set_flinprog(&mut self, val: bool)
Flush In Progress. This is an indication of the current state of afvalids.
Sourcepub const fn ftstopped(&self) -> bool
pub const fn ftstopped(&self) -> bool
Formatter stopped. The formatter has received a stop request signal and all trace data and post-amble has been output. Any more trace data on the ATB interface is ignored and atreadys goes HIGH.
Sourcepub const fn set_ftstopped(&mut self, val: bool)
pub const fn set_ftstopped(&mut self, val: bool)
Formatter stopped. The formatter has received a stop request signal and all trace data and post-amble has been output. Any more trace data on the ATB interface is ignored and atreadys goes HIGH.