#[repr(transparent)]pub struct Itctrl(pub u32);Expand description
Integration Mode Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Itctrl
impl Itctrl
Sourcepub const fn integration_mode(&self) -> bool
pub const fn integration_mode(&self) -> bool
Allows the component to switch from functional mode to integration mode or back.
Sourcepub const fn set_integration_mode(&mut self, val: bool)
pub const fn set_integration_mode(&mut self, val: bool)
Allows the component to switch from functional mode to integration mode or back.