#[repr(transparent)]pub struct Periphid1(pub u32);Expand description
Peripheral ID1 Register
Tuple Fields
0: u32Implementations
Sourceimpl Periphid1
impl Periphid1
Sourcepub const fn part_1(&self) -> u8
pub const fn part_1(&self) -> u8
Bits [11:8] of the component’s part number. This is selected by the designer of the component.
Sourcepub const fn set_part_1(&mut self, val: u8)
pub const fn set_part_1(&mut self, val: u8)
Bits [11:8] of the component’s part number. This is selected by the designer of the component.