#[repr(transparent)]pub struct Rrp(pub u32);Expand description
ETB RAM Read Pointer Register
Tuple Fields
0: u32Implementations
Sourceimpl Rrp
impl Rrp
Sourcepub const fn ram_read_pointer(&self) -> u16
pub const fn ram_read_pointer(&self) -> u16
Sets the read pointer used to read entries from the Trace RAM over the APB interface.
Sourcepub const fn set_ram_read_pointer(&mut self, val: u16)
pub const fn set_ram_read_pointer(&mut self, val: u16)
Sets the read pointer used to read entries from the Trace RAM over the APB interface.