#[repr(transparent)]pub struct Rwp(pub u32);Expand description
ETB RAM Write Pointer Register
Tuple Fields
0: u32Implementations
Sourceimpl Rwp
impl Rwp
Sourcepub const fn ram_write_pointer(&self) -> u16
pub const fn ram_write_pointer(&self) -> u16
Sets the write pointer used to write entries from the CoreSight bus into the Trace RAM.
Sourcepub const fn set_ram_write_pointer(&mut self, val: u16)
pub const fn set_ram_write_pointer(&mut self, val: u16)
Sets the write pointer used to write entries from the CoreSight bus into the Trace RAM.